@@ -1,5 +1,5 @@
 use ecs_rust::world::World;
-use ecs_rust::entity_manager::EntityManager;
+use ecs_rust::entity_manager::{EntityIdAccessor, EntityManager};
 use ecs_rust::component::Component;
 use ecs_rust::system::System;
 
@@ -13,7 +13,7 @@ impl Component for Person {
 }
 
 impl System for HelloSystem {
-	fn update(&mut self, manager: &mut EntityManager) {
+	fn update(&mut self, manager: &mut EntityManager, _accessor: &mut EntityIdAccessor) {
 		let people = manager.borrow_components::<Person>().unwrap();
 		for p in people.iter() {
 			println!("Hello {}", p.name);
