@@ -1,9 +1,10 @@
-use super::entity_manager::EntityManager;
+use super::entity_manager::{EntityIdAccessor, EntityManager};
 use super::component::Component;
 use super::system::System;
 
 pub struct World {
 	entity_manager: EntityManager,
+	entity_id_accessor: EntityIdAccessor,
 	systems: Vec<Box<dyn System>>
 }
 
@@ -11,6 +12,7 @@ impl World {
 	pub fn new() -> Self {
 		World {
 			entity_manager: EntityManager::new(),
+			entity_id_accessor: EntityIdAccessor::new(),
 			systems: vec![]
 		}
 	}
@@ -19,6 +21,10 @@ impl World {
 		self.entity_manager.create_entity()
 	}
 
+	pub fn remove_entity(&mut self, entity_id: usize) {
+		self.entity_manager.remove_entity(entity_id);
+	}
+
 	pub fn register_component<T: 'static + Component>(&mut self) -> &mut Self {
 		self.entity_manager.register::<T>();
 		self
@@ -36,7 +42,8 @@ impl World {
 
 	pub fn update(&mut self) {
 		for system in self.systems.iter_mut() {
-			system.update(&mut self.entity_manager);
+			system.update(&mut self.entity_manager, &mut self.entity_id_accessor);
+			self.entity_manager.increment_frame();
 		}
 	}
 }
